package com.aucma.report.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.aucma.report.mapper.PerfusionRecordMapper;
import com.aucma.report.domain.PerfusionRecord;
import com.aucma.report.service.IPerfusionRecordService;

/**
 * 灌注记录Service业务层处理
 * 
 * @author Yinq
 * @date 2024-03-14
 */
@Service
public class PerfusionRecordServiceImpl implements IPerfusionRecordService 
{
    @Autowired
    private PerfusionRecordMapper perfusionRecordMapper;

    /**
     * 查询灌注记录
     * 
     * @param objId 灌注记录主键
     * @return 灌注记录
     */
    @Override
    public PerfusionRecord selectPerfusionRecordByObjId(Long objId)
    {
        return perfusionRecordMapper.selectPerfusionRecordByObjId(objId);
    }

    /**
     * 查询灌注记录列表
     * 
     * @param perfusionRecord 灌注记录
     * @return 灌注记录
     */
    @Override
    public List<PerfusionRecord> selectPerfusionRecordList(PerfusionRecord perfusionRecord)
    {
        return perfusionRecordMapper.selectPerfusionRecordList(perfusionRecord);
    }

    /**
     * 新增灌注记录
     * 
     * @param perfusionRecord 灌注记录
     * @return 结果
     */
    @Override
    public int insertPerfusionRecord(PerfusionRecord perfusionRecord)
    {
        return perfusionRecordMapper.insertPerfusionRecord(perfusionRecord);
    }

    /**
     * 修改灌注记录
     * 
     * @param perfusionRecord 灌注记录
     * @return 结果
     */
    @Override
    public int updatePerfusionRecord(PerfusionRecord perfusionRecord)
    {
        return perfusionRecordMapper.updatePerfusionRecord(perfusionRecord);
    }

    /**
     * 批量删除灌注记录
     * 
     * @param objIds 需要删除的灌注记录主键
     * @return 结果
     */
    @Override
    public int deletePerfusionRecordByObjIds(Long[] objIds)
    {
        return perfusionRecordMapper.deletePerfusionRecordByObjIds(objIds);
    }

    /**
     * 删除灌注记录信息
     * 
     * @param objId 灌注记录主键
     * @return 结果
     */
    @Override
    public int deletePerfusionRecordByObjId(Long objId)
    {
        return perfusionRecordMapper.deletePerfusionRecordByObjId(objId);
    }
}
