package com.aucma.report.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.aucma.common.utils.DateUtils;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.aucma.common.annotation.Log;
import com.aucma.common.core.controller.BaseController;
import com.aucma.common.core.domain.AjaxResult;
import com.aucma.common.enums.BusinessType;
import com.aucma.report.domain.PerfusionRecord;
import com.aucma.report.service.IPerfusionRecordService;
import com.aucma.common.utils.poi.ExcelUtil;
import com.aucma.common.core.page.TableDataInfo;

/**
 * 灌注记录Controller
 *
 * @author Yinq
 * @date 2024-03-14
 */
@RestController
@RequestMapping("/report/perfusionRecord")
public class PerfusionRecordController extends BaseController {
    @Autowired
    private IPerfusionRecordService perfusionRecordService;

    /**
     * 查询灌注记录列表
     */
//    @PreAuthorize("@ss.hasPermi('report:perfusionRecord:list')")
    @GetMapping("/list")
    public TableDataInfo list(PerfusionRecord perfusionRecord) {
        startPage();
        List<PerfusionRecord> list = perfusionRecordService.selectPerfusionRecordList(perfusionRecord);
        return getDataTable(list);
    }

    /**
     * 导出灌注记录列表
     */
//    @PreAuthorize("@ss.hasPermi('report:perfusionRecord:export')")
    @Log(title = "灌注记录", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, PerfusionRecord perfusionRecord) {
        List<PerfusionRecord> list = perfusionRecordService.selectPerfusionRecordList(perfusionRecord);
        ExcelUtil<PerfusionRecord> util = new ExcelUtil<PerfusionRecord>(PerfusionRecord.class);
        util.exportExcel(response, list, "灌注记录数据");
    }

    /**
     * 获取灌注记录详细信息
     */
    @PreAuthorize("@ss.hasPermi('report:perfusionRecord:query')")
    @GetMapping(value = "/{objId}")
    public AjaxResult getInfo(@PathVariable("objId") Long objId) {
        return success(perfusionRecordService.selectPerfusionRecordByObjId(objId));
    }

    /**
     * 新增灌注记录
     */
    @PreAuthorize("@ss.hasPermi('report:perfusionRecord:add')")
    @Log(title = "灌注记录", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody PerfusionRecord perfusionRecord) {
        perfusionRecord.setCreatedBy(getUsername());
        perfusionRecord.setCreatedTime(DateUtils.getNowDate());
        return toAjax(perfusionRecordService.insertPerfusionRecord(perfusionRecord));
    }

    /**
     * 修改灌注记录
     */
    @PreAuthorize("@ss.hasPermi('report:perfusionRecord:edit')")
    @Log(title = "灌注记录", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody PerfusionRecord perfusionRecord) {
        perfusionRecord.setUpdatedBy(getUsername());
        perfusionRecord.setUpdatedTime(DateUtils.getNowDate());
        return toAjax(perfusionRecordService.updatePerfusionRecord(perfusionRecord));
    }

    /**
     * 删除灌注记录
     */
    @PreAuthorize("@ss.hasPermi('report:perfusionRecord:remove')")
    @Log(title = "灌注记录", businessType = BusinessType.DELETE)
    @DeleteMapping("/{objIds}")
    public AjaxResult remove(@PathVariable Long[] objIds) {
        return toAjax(perfusionRecordService.deletePerfusionRecordByObjIds(objIds));
    }
}
